@@ -1,4 +1,4 @@
-from ifg.ifg import IfgCalculator
+from ifg.calculator import IfgCalculator
 from ifg.units_converter import SiAtomicConverter, get_metal_specific_volume
 
 from ifg.metadata import __version__
